@@ -270,7 +270,8 @@ class Context:
         self,
         file: File,
         custom_meta: t.Mapping[str, str] = {},
-        custom_tags: t.Iterable[str] = []
+        custom_tags: t.Iterable[str] = [],
+        options: t.Mapping[str, str] = {}
     ) -> File:
         """Updates file's custom metadata and tags.
         Use 'None' to remove a meta entry.
@@ -282,7 +283,8 @@ class Context:
             context=self._obj,
             file=file, 
             custom_meta=custom_meta, 
-            custom_tags=custom_tags
+            custom_tags=custom_tags,
+            options=options
         )
 
     @wrap_log('context.run_command')
@@ -301,10 +303,15 @@ class Context:
         return file_id
 
     @wrap_log('context.add_labels')
-    def add_labels(self, file, labels):
+    def add_labels(
+        self, 
+        file: File, 
+        labels: t.Iterable[t.Mapping[te.Literal['name', 'value'], str]],
+        no_propagate: bool = False
+    ):
         validate_file_labels(labels)
         file_id = self.get_file_id(file)
-        return self._fileinfo.add_labels(self._obj, file_id, labels)
+        return self._fileinfo.add_labels(self._obj, file_id, labels, no_propagate)
 
     def get_labels(self, file):
         file_id = self.get_file_id(file)
@@ -315,6 +322,44 @@ class Context:
         file_id = self.get_file_id(file)
         return self._fileinfo.delete_labels(self._obj, file_id, label_ids)
 
+    @wrap_log('context.add_attributes')
+    def add_attributes(
+        self, 
+        file: File, 
+        custom_meta: t.Mapping[str, str] = {},
+        custom_tags: t.Iterable[str] = [],
+        labels: t.Iterable[t.Mapping[te.Literal['name', 'value'], str]] = []
+    ) -> File:
+
+        if not custom_meta and not custom_tags:
+            if labels:
+                self.add_labels(file, labels)
+                return file
+            else:
+                print({ 'level': 'error', 'message': 'no attributes provided in add_attributes()!' })
+                return file
+
+        new_file_id = str(uuid.uuid4())
+
+        if labels:
+            self._datalake.create_labels_file(
+                target_file={
+                    **file,
+                    'fileId': new_file_id
+                },
+                labels=labels
+            )
+
+        new_file = self.update_metadata_tags(
+            file=file, 
+            custom_meta=custom_meta, 
+            custom_tags=custom_tags, 
+            options={'new_file_id': new_file_id}
+        )
+        
+        return new_file
+
+
 def output_response(storage, response, correlation_id):
     storage.writeObject({**response, 'id': correlation_id})
 
